@@ -884,7 +884,7 @@ class Askdata(SignUp):
         from askdata import integration as ig
         return ig.normalize_columns(df)
 
-    def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en"):
+    def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en", skip_import_values=False):
 
 
         for col in df.columns:
@@ -915,7 +915,8 @@ class Askdata(SignUp):
         body = {
             "data": df.to_dict(orient="record"),
             "schema": schema,
-            "locale": locale
+            "locale": locale,
+            "defaultImportValues": skip_import_values
         }
 
         if (replace):
@@ -978,14 +979,14 @@ class Askdata(SignUp):
             response = s.put(url=url, json=settings, headers=headers)
             response.raise_for_status()
 
-        # Execute sync
-        headers = {
-            "Content-Type": "application/json",
-            "Authorization": "Bearer" + " " + self._token
-        }
-        dataset_url = self.base_url + '/smartdataset/datasets/' + dataset_id + '/sync'
-        r = requests.post(url=dataset_url, headers=headers)
-        r.raise_for_status()
+            # Execute sync
+            headers = {
+                "Content-Type": "application/json",
+                "Authorization": "Bearer" + " " + self._token
+            }
+            dataset_url = self.base_url + '/smartdataset/datasets/' + dataset_id + '/sync'
+            r = requests.post(url=dataset_url, headers=headers)
+            r.raise_for_status()
 
     def delete_agent(self, agent_slug):
         agent = self.agents_dataframe()[self.agents_dataframe()['slug'] == agent_slug.lower()]
